<?php

declare(strict_types=1);

namespace Drupal\verify_email;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Provides a listing of verify email forms.
 */
final class VerifyEmailListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    $header['label'] = ['data' => $this->t('Label')];
    $header['id'] = ['data' => $this->t('Machine name')];
    $header['url'] = ['data' => $this->t('URL')];
    $header['status'] = ['data' => $this->t('Status')];
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    /** @var \Drupal\verify_email\VerifyEmailInterface $entity */
    $row['label'] = $entity->label();
    $row['id'] = $entity->id();
    $row['url']['data']['#markup'] = '/' . $entity->getPath();
    if ($entity->status()) {
      $row['url']['data'] = [
        '#type' => 'link',
        '#title' => $row['url']['data'],
        '#url' => Url::fromRoute('verify_email.' . $entity->id()),
      ];
    }
    $row['status'] = $entity->status() ? $this->t('Enabled') : $this->t('Disabled');
    return $row + parent::buildRow($entity);
  }

}
